@@ -16,11 +16,11 @@ Proc::ProcessTable::piddler - Display all process table, open files, and network
 
 =head1 VERSION
 
-Version 0.1.0
+Version 0.2.0
 
 =cut
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.2.0';
 
 
 =head1 SYNOPSIS
@@ -63,6 +63,12 @@ of options.
 
 =head3 args hash
 
+=head4 a_inode
+
+Print a_inode types.
+
+Defaults to 0, false.
+
 =head4 dont_dedup
 
 Don't dedup the file descriptor list.
@@ -86,6 +92,22 @@ Don't resolve PTR addresses.
 
 Defaults to 0, false.
 
+=head4 fifo
+
+Print FIFOs.
+
+Defaults to 0, false.
+
+=head4 memreglib
+
+Prints memory mappaed libraries that show are of type REG.
+
+The following are used to match libraries.
+
+    /\.[0-9]+$/
+    /\.[0-9]+\.[0-9$/
+    /\.jar/
+
 =head4 pipe
 
 Print pipes.
@@ -173,17 +195,22 @@ sub new{
 						 'BRIGHT_MAGENTA',
 						 'BRIGHT_BLUE'
 						 ],
+				environ=>'BRIGHT_MAGENTA',
 				txt=>0,
 				pipe=>0,
 				unix=>0,
 				vregroot=>0,
 				dont_dedup=>0,
 				dont_resolv=>0,
+				fifo=>0,
+				a_inode=>0,
+				memreglib=>0,
 				};
     bless $self;
 
 	my @arg_feed=(
-				  'txt', 'pipe', 'unix', 'vregroot', 'dont_dedup', 'dont_resolv'
+				  'txt', 'pipe', 'unix', 'vregroot', 'dont_dedup', 'dont_resolv',
+				  'fifo', 'a_inore', 'memreglib'
 				   );
 
 	foreach my $feed ( @arg_feed ){
@@ -419,6 +446,13 @@ sub run{
 					$value=$self->timeString( $proc->{$key} );
 				}
 
+				if ( $key =~ /^environ$/ ){
+					$value=join( color( $self->{environ} ).', '.color('reset') , @{ $proc->{environ} } );
+					if ( !defined( $value ) ){
+						$value='';
+					}
+				}
+
 				if (
 					( $key =~ /flt$/ ) &&
 					( $proc->{$key} eq 0 ) &&
@@ -492,6 +526,7 @@ sub run{
 			my %rw_filehandles;
 			my %r_filehandles;
 			my %w_filehandles;
+			my %mem_filehandles;
 			my @lines=split(/\n/, $output_raw);
 			my $line_int=1;
 			while ( defined( $lines[$line_int] ) ){
@@ -522,6 +557,29 @@ sub run{
 					 ( $line_split[3] =~ /^[Uu][Nn][Ii][Xx]$/ ) &&
 					 ( ! $self->{unix} )
 					 ) ||
+					# fifo... spammy with elasticsearch and the like... only print if asked...
+					(
+					 ( $line_split[3] =~ /^[Ff][Ii][Ff][Oo]$/ ) &&
+					 ( ! $self->{fifo} )
+					 ) ||
+					# memory mapped libraries with REG type....
+					# spammy.... ES tends to have lots of these
+					(
+					 ( $line_split[3] =~ /^[Rr][Ee][Gg]$/ ) &&
+					 (
+					  ( $line_split[7] =~ /\.so$/ ) ||
+					  ( $line_split[7] =~ /\.so\.[0-9]$/ ) ||
+					  ( $line_split[7] =~ /\.so\.[0-9]+\.[0-9]+$/ ) ||
+					  ( $line_split[7] =~ /\.so\.[0-9]+\.[0-9]+\.[0-9]+$/ ) ||
+					  ( $line_split[7] =~ /\.jar$/ )
+					  ) &&
+					 ( ! $self->{memreglib} )
+					 ) ||
+					# a_inode... spammy with elasticsearch and the like... only print if asked...
+					(
+					 ( $line_split[3] =~ /^a\_inode$/ ) &&
+					 ( ! $self->{a_inode} )
+					 ) ||
 					# vreg /....can by spammy with somethings like firefox
 					(
 					 ( $line_split[3] =~ /^[Vv][Rr][Ee][Gg]$/ ) &&
@@ -534,9 +592,13 @@ sub run{
 
 				# begin deduping
 				my $name= color( $self->{file_colors}[5] ).$line_split[7].color( 'reset' );
-				if ( ! $self->{dont_dedup} ){
+				if (
+					( ! $self->{dont_dedup} ) &&
+					( ! $dont_add )
+					){
 					if (
 						( $line_split[3] =~ /[Vv][Rr][Ee][Gg]/ ) ||
+						( $line_split[3] =~ /[Rr][Ee][Gg]/ ) ||
 						( $line_split[3] =~ /[Vv][Dd][Ii][Dd]/ ) ||
 						( $line_split[3] =~ /[Vv][Cc][Hh][Rr]/ )
 						) {
@@ -568,6 +630,14 @@ sub run{
 							} else {
 								$w_filehandles{ $name }++;
 							}
+						}elsif (
+								( $line_split[2] =~ /mem/ )
+								){
+							if (! defined( $mem_filehandles{ $name } ) ) {
+								$mem_filehandles{ $name } = 1;
+							} else {
+								$mem_filehandles{ $name }++;
+							}
 						}
 					}
 				}
@@ -592,9 +662,11 @@ sub run{
 				my %rw_dedup;
 				my %r_dedup;
 				my %w_dedup;
+				my %mem_dedup;
 				foreach my $line ( @fdata ){
 					if (
 						( $line->[1] =~ /[Vv][Rr][Ee][Gg]/ ) ||
+						( $line->[1] =~ /[Rr][Ee][Gg]/ ) ||
 						( $line->[1] =~ /[Vv][Dd][Ii][Dd]/ ) ||
 						( $line->[1] =~ /[Vv][Cc][Hh][Rr]/ )
 						){
@@ -636,6 +708,13 @@ sub run{
 								}
 								$w_dedup{ $line->[5] } = 1;
 							}
+						}elsif(
+							   ( $line->[0] =~ /mem/ )
+							   ){
+							if ($mem_filehandles{ $line->[5] } > 1){
+								$line->[0]=$line->[0].'+';
+							}
+							$mem_dedup{ $line->[5] } = 1;
 						}
 
 						if ( $add_line ){
